List:Commits« Previous MessageNext Message »
From:Hakan Kuecuekyilmaz Date:October 1 2008 10:37am
Subject:bzr commit into mysql-falcon branch (hakan:292)
View as plain text  
#At bzr+ssh://bk-internal.mysql.com/bzrroot/mysql-falcon/

  292 Hakan Kuecuekyilmaz	2008-10-01
      Added Pushbuild failures overview.
modified:
  falcon_bug_statistic/falcon_bug_statistic.php
  falcon_bug_statistic/falcon_bug_statistic_text.php
  falcon_bug_statistic/include/config.inc.php
  falcon_bug_statistic/include/fbs_query.php

=== modified file 'falcon_bug_statistic/falcon_bug_statistic.php'
--- a/falcon_bug_statistic/falcon_bug_statistic.php	2008-09-26 07:04:23 +0000
+++ b/falcon_bug_statistic/falcon_bug_statistic.php	2008-10-01 10:37:36 +0000
@@ -44,14 +44,13 @@ $spacer16 = '                ';
 
 <div class="navi">
   <a href="#">
-    Bug counts
-  </a>
+    Bug counts</a>
+  <a href="#pushbuild_failures">
+    Pushbuild failures</a>
   <a href="#bug_reports_changes">
-    Bug reports/changes
-  </a>
+    Bug reports/changes</a>
   <a href="#bugs_by_developer">
-    Bugs by developer
-  </a>
+    Bugs by developer</a>
 </div>
 
 <div class="fbs_head">
@@ -90,7 +89,9 @@ $spacer16 = '                ';
                 while ($row = mysql_fetch_assoc($res_prio)) {
                     $i++;
                     $sum += $row['count'];
-                    $url = sprintf(URL, '-' . $row['priority'], $status_active_url, '');
+
+                    //             URL, priority, status, assign, metrics_ref, tags
+                    $url = sprintf(URL, '-' . $row['priority'], $status_active_url, '', '', '');
 
                     if ($i % 2) {
                         echo $spacer16 . '    <tr>' . "\n";
@@ -103,10 +104,10 @@ $spacer16 = '                ';
                 }
                 echo $spacer16 . '</tbody>' . "\n";
 
-                $url = sprintf(URL, 'all', $status_active_url, '');
+                $url = sprintf(URL, 'all', $status_active_url, '', '', '');
                 echo $spacer16 . '<tfoot>' . "\n";
                 echo $spacer16 . '    <tr>' . "\n";
-                echo $spacer16 . '        <td><a href="' . $url . '"><b>All</b><span><pre>' . $sql_prio . '</pre></span></a></td>' . "\n";
+                echo $spacer16 . '        <td><a href="' . $url . '"><strong>All</strong><span><pre>' . $sql_prio . '</pre></span></a></td>' . "\n";
                 echo $spacer16 . '        <td><strong>' . $sum . '</strong></td>' . "\n";
                 echo $spacer16 . '    </tr>' . "\n";
                 echo $spacer16 . '</tfoot>' . "\n";
@@ -133,7 +134,7 @@ $spacer16 = '                ';
                 while ($row = mysql_fetch_assoc($res_stat)) {
                     $i++;
                     $sum += $row['count'];
-                    $url = sprintf(URL, 'all', $row['status'], '');
+                    $url = sprintf(URL, 'all', '&status=' . $row['status'], '', '', '');
 
                     if ($i % 2) {
                         echo $spacer16 . '    <tr>' . "\n";
@@ -146,11 +147,11 @@ $spacer16 = '                ';
                 }
                 echo $spacer16 . '</tbody>' . "\n";
 
-                $url = sprintf(URL, 'all', $status_active_url, '');
+                $url = sprintf(URL, 'all', $status_active_url, '', '', '');
                 echo $spacer16 . '<tfoot>' . "\n";
                 echo $spacer16 . '    <tr>' . "\n";
-                echo $spacer16 . '        <td><a href="' . $url . '"><b>All</b><span><pre>' . $sql_stat . '</pre></span></a></td>' . "\n";
-                echo $spacer16 . '        <td><b>' . $sum . '</b></td>' . "\n";
+                echo $spacer16 . '        <td><a href="' . $url . '"><strong>All</strong><span><pre>' . $sql_stat . '</pre></span></a></td>' . "\n";
+                echo $spacer16 . '        <td><strong>' . $sum . '</strong></td>' . "\n";
                 echo $spacer16 . '    </tr>' . "\n";
                 echo $spacer16 . '</tfoot>' . "\n";
                 ?>
@@ -177,7 +178,7 @@ $spacer16 = '                ';
                 while ($row = mysql_fetch_assoc($res_prio_stat)) {
                     $i++;
                     $sum += $row['count'];
-                    $url = sprintf(URL, '-' . $row['priority'], $row['status'], '');
+                    $url = sprintf(URL, '-' . $row['priority'], '&status=' . $row['status'], '', '', '');
 
                     if ($i % 2) {
                         echo $spacer16 . '    <tr>' . "\n";
@@ -191,12 +192,12 @@ $spacer16 = '                ';
                 }
                 echo $spacer16 . '</tbody>' . "\n";
 
-                $url = sprintf(URL, 'all', $status_active_url, '');
+                $url = sprintf(URL, 'all', $status_active_url, '', '', '');
                 echo $spacer16 . '<tfoot>' . "\n";
                 echo $spacer16 . '    <tr>' . "\n";
-                echo $spacer16 . '        <td><a href="' . $url . '"><b>All</b><span><pre>' . $sql_prio_stat . '</pre></span></a></td>' . "\n";
+                echo $spacer16 . '        <td><a href="' . $url . '"><strong>All</strong><span><pre>' . $sql_prio_stat . '</pre></span></a></td>' . "\n";
                 echo $spacer16 . '        <td>&nbsp;</td>' . "\n";
-                echo $spacer16 . '        <td><b>' . $sum . '</b></td>' . "\n";
+                echo $spacer16 . '        <td><strong>' . $sum . '</strong></td>' . "\n";
                 echo $spacer16 . '    </tr>' . "\n";
                 echo $spacer16 . '</tfoot>' . "\n";
                 ?>
@@ -225,8 +226,7 @@ $spacer16 = '                ';
                 while ($row = mysql_fetch_assoc($res_beta_stat)) {
                     $i++;
                     $sum += $row['count'];
-                    $url = sprintf(URL, 'all', $row['status'], '');
-                    $url .= '&metrics_ref=SR60BETA';
+                    $url = sprintf(URL, 'all', '&status=' . $row['status'], '', 'SR60BETA', '');
 
                     if ($i % 2) {
                         echo $spacer16 . '    <tr>' . "\n";
@@ -240,13 +240,12 @@ $spacer16 = '                ';
                 }
                 echo $spacer16 . '</tbody>' . "\n";
 
-                $url = sprintf(URL, 'all', $status_active_url, '');
-                $url .= '&metrics_ref=SR60BETA';
+                $url = sprintf(URL, 'all', $status_active_url, '', 'SR60BETA', '');
                 echo $spacer16 . '<tfoot>' . "\n";
                 echo $spacer16 . '    <tr>' . "\n";
-                echo $spacer16 . '        <td><a href="' . $url . '"><b>All</b><span><pre>' . $sql_beta_stat . '</pre></span></a></td>' . "\n";
+                echo $spacer16 . '        <td><a href="' . $url . '"><strong>All</strong><span><pre>' . $sql_beta_stat . '</pre></span></a></td>' . "\n";
                 echo $spacer16 . '        <td>&nbsp;</td>' . "\n";
-                echo $spacer16 . '        <td><b>' . $sum . '</b></td>' . "\n";
+                echo $spacer16 . '        <td><strong>' . $sum . '</strong></td>' . "\n";
                 echo $spacer16 . '    </tr>' . "\n";
                 echo $spacer16 . '</tfoot>' . "\n";
                 ?>
@@ -273,8 +272,7 @@ $spacer16 = '                ';
                 while ($row = mysql_fetch_assoc($res_rc_stat)) {
                     $i++;
                     $sum += $row['count'];
-                    $url = sprintf(URL, 'all', $row['status'], '');
-                    $url .= '&metrics_ref=SR60RC';
+                    $url = sprintf(URL, 'all', '&status=' . $row['status'], '', 'SR60RC', '');
 
                     if ($i % 2) {
                         echo $spacer16 . '    <tr>' . "\n";
@@ -288,13 +286,12 @@ $spacer16 = '                ';
                 }
                 echo $spacer16 . '</tbody>' . "\n";
 
-                $url = sprintf(URL, 'all', $status_active_url, '');
-                $url .= '&metrics_ref=SR60RC';
+                $url = sprintf(URL, 'all', $status_active_url, '', 'SR60RC', '');
                 echo $spacer16 . '<tfoot>' . "\n";
                 echo $spacer16 . '    <tr>' . "\n";
-                echo $spacer16 . '        <td><a href="' . $url . '"><b>All</b><span><pre>' . $sql_rc_stat . '</pre></span></a></td>' . "\n";
+                echo $spacer16 . '        <td><a href="' . $url . '"><strong>All</strong><span><pre>' . $sql_rc_stat . '</pre></span></a></td>' . "\n";
                 echo $spacer16 . '        <td>&nbsp;</td>' . "\n";
-                echo $spacer16 . '        <td><b>' . $sum . '</b></td>' . "\n";
+                echo $spacer16 . '        <td><strong>' . $sum . '</strong></td>' . "\n";
                 echo $spacer16 . '    </tr>' . "\n";
                 echo $spacer16 . '</tfoot>' . "\n";
                 ?>
@@ -322,7 +319,7 @@ $spacer16 = '                ';
                 while ($row = mysql_fetch_assoc($res_stat_inactive)) {
                     $i++;
                     $sum += $row['count'];
-                    $url = sprintf(URL, 'all', $row['status'], '');
+                    $url = sprintf(URL, 'all', '&status=' . $row['status'], '', '', '');
 
 
                     if ($i % 2) {
@@ -336,11 +333,11 @@ $spacer16 = '                ';
                 }
                 echo $spacer16 . '</tbody>' . "\n";
 
-                $url = sprintf(URL, 'all', $status_inactive_url, '');
+                $url = sprintf(URL, 'all', $status_inactive_url, '', '', '');
                 echo $spacer16 . '<tfoot>' . "\n";
                 echo $spacer16 . '    <tr>' . "\n";
-                echo $spacer16 . '        <td><a href="' . $url . '"><b>All</b><span><pre>' . $sql_stat_inactive . '</pre></span></a></td>' . "\n";
-                echo $spacer16 . '        <td><b>' . $sum . '</b></td>' . "\n";
+                echo $spacer16 . '        <td><a href="' . $url . '"><strong>All</strong><span><pre>' . $sql_stat_inactive . '</pre></span></a></td>' . "\n";
+                echo $spacer16 . '        <td><strong>' . $sum . '</strong></td>' . "\n";
                 echo $spacer16 . '    </tr>' . "\n";
                 echo $spacer16 . '</tfoot>' . "\n";
                 ?>
@@ -352,6 +349,63 @@ $spacer16 = '                ';
     <br />
 </div>
 
+<a name="pushbuild_failures"></a>
+<div class="fbs">
+    <div class="sorted">
+    <table class="table-autosort table-stripeclass:alternate">
+        <thead>
+            <tr>
+                <th colspan="6"><h2>Falcon related Pushbuild failures</h2></th>
+            </tr>
+            <tr class="alternate">
+                <th class="table-sortable:numeric"><h3>Id</h3></th>
+                <th class="table-sortable:numeric"><h3>Priority</h3></th>
+                <th class="table-sortable:default"><h3>Status</h3></th>
+                <th class="table-sortable:default"><h3>OS</h3></th>
+                <th class="table-sortable:default"><h3>Assignee</h3></th>
+                <th class="table-sortable:default"><h3>Short description</h3></th>
+            </tr>
+        </thead>
+        <?php
+        $i = 0;
+        $sum = 0;
+
+        echo '<tbody>' . "\n";
+        while ($row = mysql_fetch_assoc($res_pushbuild_failures)) {
+            $i++;
+            $url = sprintf('http://bugs.mysql.com/%d', $row[id]);
+
+            if ($i % 2) {
+                echo $spacer8 . '    <tr>' . "\n";
+            } else {
+                echo $spacer8 . '    <tr class="alternate">' . "\n";
+            }
+            echo $spacer8 . '        <td><a href="' . $url . '">' . $row['id'] . '</a></td>' . "\n";
+            echo $spacer8 . '        <td>' . $row['priority'] . '</td>' . "\n";
+            echo $spacer8 . '        <td>' . $row['status'] . '</td>' . "\n";
+            echo $spacer8 . '        <td>' . $row['os'] . '</td>' . "\n";
+            echo $spacer8 . '        <td>' . $row['firstname'] . ' ' . $row['lastname'] . '</td>' . "\n";
+            echo $spacer8 . '        <td>' . $row['sdesc'] . '</td>' . "\n";
+            echo $spacer8 . '    </tr>' . "\n";
+        }
+        echo $spacer8 . '</tbody>' . "\n";
+
+        $url = sprintf(URL, 'all', $status_active_url, '', '', $tags_url);
+        echo $spacer8 . '<tfoot>' . "\n";
+        echo $spacer8 . '    <tr>' . "\n";
+        echo $spacer8 . '        <td><a href="' . $url . '"><strong>All</strong><span><pre>' . $sql_pushbuild_failures . '</pre></span></a></td>' . "\n";
+        echo $spacer8 . '        <td>&nbsp;</td>' . "\n";
+        echo $spacer8 . '        <td>&nbsp;</td>' . "\n";
+        echo $spacer8 . '        <td>&nbsp;</td>' . "\n";
+        echo $spacer8 . '        <td>&nbsp;</td>' . "\n";
+        echo $spacer8 . '        <td><strong>' . $i . '</strong></td>' . "\n";
+        echo $spacer8 . '    </tr>' . "\n";
+        echo $spacer8 . '</tfoot>' . "\n";
+        ?>
+    </table>
+    </div>
+</div>
+
 <?php
 $values= array(7, 14, 21, 30);
 
@@ -430,10 +484,10 @@ echo '</div>' . "\n";
 
         echo $spacer8 . '<tfoot>' . "\n";
         echo $spacer8 . '    <tr>' . "\n";
-        echo $spacer8 . '        <td><a><b>All</b><span><pre>' . $sql_last_bugs . '</pre></span></a></td>' . "\n";
+        echo $spacer8 . '        <td><a><strong>All</strong><span><pre>' . $sql_last_bugs . '</pre></span></a></td>' . "\n";
         echo $spacer8 . '        <td>&nbsp;</td>' . "\n";
         echo $spacer8 . '        <td>&nbsp;</td>' . "\n";
-        echo $spacer8 . '        <td><b>' . $i . '</b></td>' . "\n";
+        echo $spacer8 . '        <td><strong>' . $i . '</strong></td>' . "\n";
         echo $spacer8 . '    </tr>' . "\n";
         echo $spacer8 . '</tfoot>' . "\n";
         ?>
@@ -480,10 +534,10 @@ echo '</div>' . "\n";
 
         echo $spacer8 . '<tfoot>' . "\n";
         echo $spacer8 . '    <tr>' . "\n";
-        echo $spacer8 . '        <td><a><b>All</b><span><pre>' . $sql_last_status_changes . '</pre></span></a></td>' . "\n";
+        echo $spacer8 . '        <td><a><strong>All</strong><span><pre>' . $sql_last_status_changes . '</pre></span></a></td>' . "\n";
         echo $spacer8 . '        <td>&nbsp;</td>' . "\n";
         echo $spacer8 . '        <td>&nbsp;</td>' . "\n";
-        echo $spacer8 . '        <td><b>' . $i . '</b></td>' . "\n";
+        echo $spacer8 . '        <td><strong>' . $i . '</strong></td>' . "\n";
         echo $spacer8 . '    </tr>' . "\n";
         echo $spacer8 . '</tfoot>' . "\n";
         ?>
@@ -516,7 +570,7 @@ echo '</div>' . "\n";
         while ($row = mysql_fetch_assoc($res_developer_status)) {
             $i++;
             $sum += $row['count'];
-            $url = sprintf(URL, 'all', $row['status'], $row['assign']);
+            $url = sprintf(URL, 'all', '&status=' . $row['status'], $row['assign'], '', '');
 
             if ($i % 2) {
                 echo $spacer8 . '    <tr>' . "\n";
@@ -532,9 +586,9 @@ echo '</div>' . "\n";
 
         echo $spacer8 . '<tfoot>' . "\n";
         echo $spacer8 . '    <tr>' . "\n";
-        echo $spacer8 . '        <td><a><b>All</b><span><pre>' . $sql_developer_status . '</pre></span></a></td>' . "\n";
+        echo $spacer8 . '        <td><a><strong>All</strong><span><pre>' . $sql_developer_status . '</pre></span></a></td>' . "\n";
         echo $spacer8 . '        <td>&nbsp;</td>' . "\n";
-        echo $spacer8 . '        <td><b>' . $sum . '</b></td>' . "\n";
+        echo $spacer8 . '        <td><strong>' . $sum . '</strong></td>' . "\n";
         echo $spacer8 . '    </tr>' . "\n";
         echo $spacer8 . '</tfoot>' . "\n";
 

=== modified file 'falcon_bug_statistic/falcon_bug_statistic_text.php'
--- a/falcon_bug_statistic/include/config.inc.php	2008-09-26 07:04:23 +0000
+++ b/falcon_bug_statistic/include/config.inc.php	2008-10-01 10:37:36 +0000
@@ -48,38 +48,40 @@ define('THIS_DATE', date("F jS, Y - H:i:
  * Status fields used in queries.
  */
 $status_active = "
-    'Analyzing',
-    'Documenting',
-    'In progress',
-    'In review',
-    'Need Doc Info',
-    'Need Feedback',
-    'No Feedback',
-    'Open',
-    'Patch approved',
-    'Patch pending',
-    'Patch queued',
-    'Post-fix test fail',
-    'QA review',
-    'QA testing',
-    'Verified'
+        'Analyzing',
+        'Documenting',
+        'In progress',
+        'In review',
+        'Need Doc Info',
+        'Need Feedback',
+        'No Feedback',
+        'Open',
+        'Patch approved',
+        'Patch pending',
+        'Patch queued',
+        'Post-fix test fail',
+        'QA review',
+        'QA testing',
+        'Verified'
 ";
 
+$status_active_url= '';
 $tmp = explode(',', $status_active);
 foreach ($tmp as $data) {
     $status_active_url .= '&status[]=' . str_replace("'", '', trim($data));
 }
 
 $status_inactive = "
-    'Can\'t repeat',
-    'Closed',
-    'Duplicate',
-    'Not a Bug',
-    'To be fixed later',
-    'Unsupported',
-    'Won\'t fix'
+        'Can\'t repeat',
+        'Closed',
+        'Duplicate',
+        'Not a Bug',
+        'To be fixed later',
+        'Unsupported',
+        'Won\'t fix'
 ";
 
+$status_inactive_url = '';
 $tmp = explode(',', $status_inactive);
 foreach ($tmp as $data) {
     $status_inactive_url .= '&status[]=' . str_replace("'", '', trim($data));
@@ -87,14 +89,32 @@ foreach ($tmp as $data) {
 $status_inactive_url = str_replace('Can\t', "Can't", $status_inactive_url);
 $status_inactive_url = str_replace('Won\t', "Won't", $status_inactive_url);
 
+$tags = "
+        'Pushbuild',
+        'test_failure',
+        'test case failure',
+        'test failure',
+        'test failures'
+";
+
+$tags_url = '';
+$tmp = explode(',', $tags);
+foreach ($tmp as $data) {
+    $tags_url .= str_replace("'", '', trim($data)) . '%2C';
+}
+// Get rid of last urlencoded comma.
+$tags_url = substr($tags_url, 0, -3);
+
 /**
  * URL for bugs.mysql.com.
  */
 define('URL', 'http://bugs.mysql.com/search.php'
-  . '?bug_type=Server%%3A+Falcon'
+  . '?bug_type[]=Server%%3A+Falcon'
   . '&priority=%s'
-  . '&status=%s'
+  . '%s' /* status= || status[]= */
   . '&assign=%s'
+  . '&metrics_ref=%s'
+  . '&tags=%s'
   . '&limit=All'
   . '&order_by=id'
   . '&direction=DESC'
@@ -143,6 +163,7 @@ define('P_S_C',    './priority_status_co
 define('B_S_C',    './beta_status_count.tab');
 define('R_S_C',    './rc_status_count.tab');
 define('I_S_C',    './inactive_status_count.tab');
+define('P_F',      './pushbuild_failures.tab');
 define('B_P_S_S',  './bugnumber_priority_status_shortdescription.tab');
 define('B_P_S_SY', './bugnumber_priority_status_synopsis.tab');
 define('D_S_C',    './developer_status_count.tab');

=== modified file 'falcon_bug_statistic/include/fbs_query.php'
--- a/falcon_bug_statistic/include/fbs_query.php	2008-09-26 07:04:23 +0000
+++ b/falcon_bug_statistic/include/fbs_query.php	2008-10-01 10:37:36 +0000
@@ -27,32 +27,32 @@ if (!isset($date) || $date == '') {
 }
 
 $sql_prio = "SELECT priority, count(*) AS count FROM bugdb
-  WHERE status IN ($status_active)
+  WHERE status IN ($status_active        )
     AND severity <> 4
     AND bug_type = 'Server: Falcon'
   GROUP BY priority";
 
 $sql_stat = "SELECT status, count(*) AS count FROM bugdb
-  WHERE status IN ($status_active)
+  WHERE status IN ($status_active        )
     AND severity <> 4
     AND bug_type = 'Server: Falcon'
   GROUP BY status";
 
 $sql_prio_stat =  "SELECT priority, status, count(*) AS count FROM bugdb
-  WHERE status IN ($status_active)
+  WHERE status IN ($status_active        )
     AND severity <> 4
     AND bug_type = 'Server: Falcon'
   GROUP BY priority, status";
 
 $sql_beta_stat =  "SELECT metrics_ref, status, count(*) AS count FROM bugdb
-  WHERE status IN ($status_active)
+  WHERE status IN ($status_active        )
     AND severity <> 4
     AND bug_type = 'Server: Falcon'
     AND metrics_ref = 'SR60BETA'
   GROUP BY status";
 
 $sql_rc_stat =  "SELECT metrics_ref, status, count(*) AS count FROM bugdb
-  WHERE status IN ($status_active)
+  WHERE status IN ($status_active        )
     AND severity <> 4
     AND bug_type = 'Server: Falcon'
     AND metrics_ref = 'SR60RC'
@@ -77,18 +77,31 @@ $sql_developer_status =
     "SELECT assign, status, count(*) AS count
 FROM bugdb
   WHERE assign IN ($developer_keys)
-    AND status IN ($status_active)
+    AND status IN ($status_active        )
     AND bug_type = 'Server: Falcon'
   GROUP BY assign, status
   ORDER BY assign DESC";
 
 $sql_stat_inactive =
     "SELECT status, count(*) AS count FROM bugdb
-WHERE status IN ($status_inactive)
+WHERE status IN ($status_inactive        )
   AND severity <> 4
   AND bug_type = 'Server: Falcon'
 GROUP BY status";
 
+$sql_pushbuild_failures =
+  "SELECT bugdb.id, bugdb.priority, bugdb.sdesc, bugdb.status,
+        os.name as os, user.firstname, user.lastname
+  FROM bugdb LEFT JOIN user ON (bugdb.assign = user.user_id), bug_to_tag, tag, os
+    WHERE bugdb.bug_type = 'Server: Falcon'
+      AND bugdb.id = bug_to_tag.bug
+      AND bug_to_tag.tag = tag.id
+      AND bugdb.os = os.id
+      AND tag.name IN ($tags        )
+      AND bugdb.status IN ($status_active        )
+  GROUP BY bugdb.id
+  ORDER BY bugdb.id DESC";
+
 $res_prio = mysql_query($sql_prio);
 $res_stat = mysql_query($sql_stat);
 $res_prio_stat = mysql_query($sql_prio_stat);
@@ -98,5 +111,6 @@ $res_last_bugs = mysql_query($sql_last_b
 $res_last_status_changes = mysql_query($sql_last_status_changes);
 $res_developer_status = mysql_query($sql_developer_status);
 $res_stat_inactive = mysql_query($sql_stat_inactive);
+$res_pushbuild_failures = mysql_query($sql_pushbuild_failures);
 
 ?>

Thread
bzr commit into mysql-falcon branch (hakan:292) Hakan Kuecuekyilmaz1 Oct
--- a/falcon_bug_statistic/falcon_bug_statistic_text.php	2008-09-26 04:57:38 +0000
+++ b/falcon_bug_statistic/falcon_bug_statistic_text.php	2008-10-01 10:37:36 +0000
@@ -29,20 +29,24 @@ $ah = 20;
 $ch = 7;
 $ih = 6;
 $mh = 10;
-$ph = 9;
+$oh = 17;
+$ph = 5;
 $sh = 17;
 $cv = 3;
 
 $dh = $line - $ih - $ph - $sh;
+$d2h = $line - $ih - $ph - $sh - $oh - $ad;
 
-define('A_HEADER', '%-' . $ah . 's');
-define('C_HEADER', '%-' . $ch . 's');
-define('I_HEADER', '%-' . $ih . 's');
-define('M_HEADER', '%-' . $mh . 's');
-define('P_HEADER', '%-' . $ph . 's');
-define('S_HEADER', '%-' . $sh . 's');
-define('D_HEADER', '%-' . $dh . 's');
-define('C_VALUE', '%' . $cv . 'd');
+define('A_HEADER',  '%-' . $ah  . 's');
+define('C_HEADER',  '%-' . $ch  . 's');
+define('I_HEADER',  '%-' . $ih  . 's');
+define('M_HEADER',  '%-' . $mh  . 's');
+define('O_HEADER',  '%-' . $oh  . 's');
+define('P_HEADER',  '%-' . $ph  . 's');
+define('S_HEADER',  '%-' . $sh  . 's');
+define('D_HEADER',  '%-' . $dh  . 's');
+define('D2_HEADER', '%-' . $d2h . 's');
+define('C_VALUE',   '%'  . $cv  . 'd');
 
 /**
  * Horizontal rules.
@@ -58,7 +62,13 @@ $hr_msc =  str_repeat('-', $mh) . '+' . 
 $hr_ipsd = str_repeat('-', $ih) . '+' . str_repeat('-', $ph + 1)
            . '+' . str_repeat('-', $sh + 1) . '+' . str_repeat('-', $dh) . "\n";
 $hre_ipsd = "\n" . str_repeat(' ', $ih) . '|' . str_repeat(' ', $ph + 1)
-           . '|' . str_repeat(' ', $sh + 1) . '| ';
+            . '|' . str_repeat(' ', $sh + 1) . '| ';
+$hr_ipsoad = str_repeat('-', $ih) . '+' . str_repeat('-', $ph + 1)
+             . '+' . str_repeat('-', $sh + 1) . '+' . str_repeat('-', $oh + 1)
+             . '+' . str_repeat('-', $ah + 1) . '+' . str_repeat('-', $d2h) . "\n";
+$hre_ipsoad = "\n" . str_repeat(' ', $ih) . '|' . str_repeat(' ', $ph + 1)
+              . '|' . str_repeat(' ', $sh + 1) . '|' . str_repeat(' ', $oh + 1)
+              . '|' . str_repeat(' ', $ah + 1) . '| ';
 
 /**
  * Text output.
@@ -77,14 +87,14 @@ echo 'https://intranet.mysql.com/~hakank
 echo "\n";
 
 /**
- * Priority | Count.
+ * Prio | Count.
  */
 echo $hr_pc;
-printf(P_HEADER . '| ' . C_HEADER . "\n",  'Priority', 'Count');
+printf(P_HEADER . '| ' . C_HEADER . "\n",  'Prio', 'Count');
 echo $hr_pc;
 
 $f = fopen(P_C, 'w');
-fwrite($f, 'Priority' . DL . 'Count' . "\n");
+fwrite($f, 'Prio' . DL . 'Count' . "\n");
 
 $sum = 0;
 while ($row = mysql_fetch_assoc($res_prio)) {
@@ -125,14 +135,14 @@ echo "\n";
 echo "\n";
 
 /**
  * Priority | Status | Count.
  */
 echo $hr_psc;
-printf(P_HEADER . '| ' . S_HEADER . '| ' . C_HEADER . "\n",  'Priority', 'Status', 'Count');
+printf(P_HEADER . '| ' . S_HEADER . '| ' . C_HEADER . "\n",  'Prio', 'Status', 'Count');
 echo $hr_psc;
 
 $f = fopen(P_S_C, 'w');
-fwrite($f, 'Priority' . DL . 'Status' . DL . 'Count' . "\n");
+fwrite($f, 'Prio' . DL . 'Status' . DL . 'Count' . "\n");
 
 $sum = 0;
 while ($row = mysql_fetch_assoc($res_prio_stat)) {
@@ -202,7 +212,7 @@ echo "\n";
  * Inactive Status | Count.
  */
 echo $hr_sc;
-echo '     Inactive bugs.' . "\n";
+echo '      Inactive bugs' . "\n";
 echo $hr_sc;
 printf(S_HEADER . '| ' . C_HEADER . "\n",  'Status', 'Count');
 echo $hr_sc;
@@ -225,16 +235,47 @@ echo "\n";
 echo "\n";
 
 /**
- * Id | Priority | Status | Short description.
+ * Id | Prio | Status | OS | Assignee | Short description.
+ */
+echo 'Falcon related Pusbuild failures.' . "\n";
+echo $hr_ipsoad;
+printf(I_HEADER . '| ' . P_HEADER . '| ' . S_HEADER . '| ' . O_HEADER . '| ' . A_HEADER . '| ' . D2_HEADER . "\n",
+       'Id', 'Prio', 'Status', 'OS', 'Assignee', 'Short description');
+echo $hr_ipsoad;
+
+$f = fopen(P_F, 'w');
+fwrite($f, 'Bug Id'. DL . 'Prio' . DL . 'Status' . DL . 'Short description' . "\n");
+
+$sum = 0;
+while ($row = mysql_fetch_assoc($res_pushbuild_failures)) {
+    $sum++;
+    $sdesc = wordwrap($row['sdesc'], $d2h - 1, $hre_ipsoad);
+
+    printf(I_HEADER . '| ' . P_HEADER . '| ' . S_HEADER . '| ' . O_HEADER . '| ' . A_HEADER . '| ' . D2_HEADER . "\n",
+           $row['id'], $row['priority'], $row['status'], $row['os'], $row['firstname'] . ' ' . $row['lastname'], $sdesc);
+    echo $hr_ipsoad;
+    fwrite($f, $row['id'] . DL . $row['priority'] . DL . $row['status'] . DL . $row['OS'] . DL . $row['sdesc'] . DL .  $row['firstname'] . ' ' . $row['lastname'] . "\n");
+}
+echo $hr_ipsoad;
+printf(I_HEADER . '| ' . P_HEADER . '| ' . S_HEADER . '| ' . O_HEADER . '| ' . A_HEADER . '| ' . D2_HEADER . "\n",
+       'All', '', '', '', '', $sum);
+
+fclose($f);
+
+echo "\n";
+echo "\n";
+
+/**
+ * Id | Prio | Status | Short description.
  */
 echo 'Falcon related bugs, which were newly reported in the last ' . $days . "\n";
 echo $hr_ipsd;
 printf(I_HEADER . '| ' . P_HEADER . '| ' . S_HEADER . '| ' . D_HEADER . "\n",
-       'Id', 'Priority', 'Status', 'Short description');
+       'Id', 'Prio', 'Status', 'Short description');
 echo $hr_ipsd;
 
 $f = fopen(B_P_S_S, 'w');
-fwrite($f, 'Bug Id'. DL . 'Priority' . DL . 'Status' . DL . 'Short description' . "\n");
+fwrite($f, 'Bug Id'. DL . 'Prio' . DL . 'Status' . DL . 'Short description' . "\n");
 
 $sum = 0;
 while ($row = mysql_fetch_assoc($res_last_bugs)) {
@@ -256,16 +297,16 @@ echo "\n";
 echo "\n";
 
 /**
  * Id | Priority | Status | Synopsis and change
  */
 echo 'Falcon related bugs, which changed their status in the last ' . $days . "\n";
 echo $hr_ipsd;
 printf(I_HEADER . '| ' . P_HEADER . '| ' . S_HEADER . '| ' . D_HEADER . "\n",
-       'Id', 'Priority', 'Status', 'Synopsis and change');
+       'Id', 'Prio', 'Status', 'Synopsis and change');
 echo $hr_ipsd;
 
 $f = fopen(B_P_S_SY, 'w');
-fwrite($f, 'Bug Id'. DL . 'Priority' . DL . 'Status' . DL . 'Synopsis and change' . "\n");
+fwrite($f, 'Bug Id'. DL . 'Prio' . DL . 'Status' . DL . 'Synopsis and change' . "\n");
 
 $sum = 0;
 while ($row = mysql_fetch_assoc($res_last_status_changes)) {
@@ -125,14 +135,14 @@ echo "\n";
 
 /**
- * Priority | Status | Count.
+ * Prio | Status | Count.
  */
 echo $hr_psc;
@@ -256,16 +297,16 @@ echo "\n";
 
 /**
- * Id | Priority | Status | Synopsis and change
+ * Id | Prio | Status | Synopsis and change
  */
 echo 'Falcon related bugs, which changed their status in the last ' . $days . "\n";

=== modified file 'falcon_bug_statistic/include/config.inc.php'